==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Widgets/PropertyEditor/ts/PropertyEditor_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>AddCustomPropertyDialog</name>
    <message>
        <location filename="../AddCustomPropertyDialog.ui" line="+14"/>
        <source>Add Custom Property</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Adicione Propriedades Personalizadas</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Name:</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Nome do Carimbo:
Nome do bloco:
Nome da Camada:</translatorcomment>
        <translation>Nome:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Value:</source>
        <translation>Valor:</translation>
    </message>
    <message>
        <source>Type:</source>
        <translatorcomment>--exact match--
--file: pt.po--
Tipo de linha:</translatorcomment>
        <translation type="obsolete">Tipo:</translation>
    </message>
</context>
<context>
    <name>PropertyEditor</name>
    <message>
        <location filename="../PropertyEditor.js" line="+1320"/>
        <source>*VARIES*</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>*VARIA*</translation>
    </message>
    <message>
        <location line="-1132"/>
        <source>:</source>
        <translatorcomment>--ignored colon--
--file: pt.po--
Desenho guardado: %1
Documento carregado: %1</translatorcomment>
        <translation>:</translation>
    </message>
    <message>
        <location line="+150"/>
        <source>No Selection</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Nenhuma Seleção</translation>
    </message>
    <message>
        <source>Geometry</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Modifique propriedades e geometria de entidade
Geometria</translatorcomment>
        <translation type="vanished">Geometria</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Specific Properties</source>
        <translation>Propriedades específicas</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Dependent Entities</source>
        <translation>Entidades Dependentes</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Custom</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Customize..
Personalizado
Não entidades de dimensão com posições etiqueta personalizada selecionada.</translatorcomment>
        <translation>Personalizado</translation>
    </message>
    <message>
        <location line="+166"/>
        <source>Index</source>
        <translatorcomment>--google--
Indentar nó
Trocar para a próxima camada</translatorcomment>
        <translation>Índice</translation>
    </message>
    <message>
        <location line="+59"/>
        <source>Remove this property from selected objects</source>
        <translation>Remova esta propriedade dos objetos selecionados</translation>
    </message>
    <message>
        <location line="+68"/>
        <source>All</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Fecha &amp;Todos
Fecha Todos
Fecha todas as janelas</translatorcomment>
        <translation>Todos</translation>
    </message>
    <message>
        <location line="+641"/>
        <source>Widgets</source>
        <translation>Widgets</translation>
    </message>
    <message>
        <source>Add Custom Property</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Adicionar propriedade personalizada</translation>
    </message>
    <message>
        <location line="-619"/>
        <source>Add custom property to selected objects</source>
        <translation>Adicione uma propriedade personalizada aos objetos selecionados</translation>
    </message>
    <message>
        <source>Left</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Esquerda acima
Em cima à esquerda
Esquerda ao meio</translatorcomment>
        <translation type="obsolete">Esquerda</translation>
    </message>
    <message>
        <source>Center</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
&amp;Centro, ponto, ângulos
Centro, ponto, ângulos
Arco com Centro, Ponto, Ângulos</translatorcomment>
        <translation type="obsolete">Centro</translation>
    </message>
    <message>
        <source>Right</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Direita ao meio
Direita abaixo
Em baixo à direita</translatorcomment>
        <translation type="obsolete">Direita</translation>
    </message>
    <message>
        <source>Aligned</source>
        <translatorcomment>--exact match--
--file: DimAligned_pt.ts--
&amp;Alinhado
Alinhado
Dimensão Alinhada</translatorcomment>
        <translation type="obsolete">Alinhado</translation>
    </message>
    <message>
        <source>Middle</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
&amp;Meio
Meio
Salta aos pontos de meio</translatorcomment>
        <translation type="obsolete">Meio</translation>
    </message>
    <message>
        <source>Fit</source>
        <translatorcomment>--google--
Ajuste à página
Ponto de ajustar primeiro
Ponto de ajustar próximo</translatorcomment>
        <translation type="obsolete">Caber</translation>
    </message>
    <message>
        <source>Top</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Deposita ao fim da garimpagem
Centro acima</translatorcomment>
        <translation type="obsolete">Topo</translation>
    </message>
    <message>
        <source>Base</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Desenhe arcos tangenciais à entidade de base
Arco tangencial à entidade de base com raio</translatorcomment>
        <translation type="obsolete">Base</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Direita abaixo
Em baixo à direita
Centro abaixo</translatorcomment>
        <translation type="obsolete">Fundo</translation>
    </message>
    <message>
        <location line="+136"/>
        <source>Auto</source>
        <translatorcomment>--exact match--
--file: SnapAuto_pt.ts--
&amp;Auto
Auto
Salta automaticamente</translatorcomment>
        <translation>Automático</translation>
    </message>
    <message>
        <location line="+123"/>
        <source>Use auto measurement</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Use medição automática</translation>
    </message>
    <message>
        <location line="+39"/>
        <source>Yes</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Sim
Ontem</translatorcomment>
        <translation>Sim</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>No</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Não pôde abrir o arquivo
%1
Por favor verifique as permissões.
Não pôde abrir o arquivo
%1
Por favor verifique as permissões
Não pôde salvar o arquivo
%1
Por favor verifique as permissões.</translatorcomment>
        <translation>Não</translation>
    </message>
    <message>
        <location line="+320"/>
        <location line="+57"/>
        <location line="+11"/>
        <source>Property Editor</source>
        <translatorcomment>--exact match--
--file: qcad_pt.ts--
Editor de Propriedades</translatorcomment>
        <translation>Editor de Propriedades</translation>
    </message>
    <message>
        <location filename="../PropertyEditor.ui" line="+40"/>
        <source>Selection:</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Selecção:</translatorcomment>
        <translation>Seleção:</translation>
    </message>
    <message>
        <source>General</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Preferências Gerais do Aplicativo
[2000-206F] Pontuação Geral</translatorcomment>
        <translation type="vanished">Geral</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>General Properties</source>
        <translation>Propriedades gerais</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Color:</source>
        <translation>Cor:</translation>
    </message>
    <message>
        <source>Move Selection to a New Layer</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="vanished">Mova a Seleção para uma Nova Camada</translation>
    </message>
    <message>
        <location line="+104"/>
        <source>Linetype Scale:</source>
        <translation>Escala do Tipo de Linha:</translation>
    </message>
    <message>
        <location line="+49"/>
        <source>Protected:</source>
        <translation>Protegido:</translation>
    </message>
    <message>
        <location line="-143"/>
        <source>Handle:</source>
        <translatorcomment>--ignored colon--
--file: pt.po--</translatorcomment>
        <translation>Manipulador:</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Display Z coordinates</source>
        <translation>Exiba coordenadas Z</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Display properties of current block and current layer</source>
        <translation>Exibição de propriedades de bloco atual e camada atual</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Widgets/PropertyEditor/ts/PropertyEditor_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>AddCustomPropertyDialog</name>
    <message>
        <location filename="../AddCustomPropertyDialog.ui" line="+14"/>
        <source>Add Custom Property</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Adicione Propriedades Personalizadas</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Name:</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Nome do Carimbo:
Nome do bloco:
Nome da Camada:</translatorcomment>
        <translation>Nome:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Value:</source>
        <translation>Valor:</translation>
    </message>
    <message>
        <source>Type:</source>
        <translatorcomment>--exact match--
--file: pt.po--
Tipo de linha:</translatorcomment>
        <translation type="obsolete">Tipo:</translation>
    </message>
</context>
<context>
    <name>PropertyEditor</name>
    <message>
        <location filename="../PropertyEditor.js" line="+1392"/>
        <source>*VARIES*</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>*VARIA*</translation>
    </message>
    <message>
        <location line="-1199"/>
        <source>:</source>
        <translatorcomment>--ignored colon--
--file: pt.po--
Desenho guardado: %1
Documento carregado: %1</translatorcomment>
        <translation>:</translation>
    </message>
    <message>
        <location line="+151"/>
        <source>No Selection</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Nenhuma Seleção</translation>
    </message>
    <message>
        <source>Geometry</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Modifique propriedades e geometria de entidade
Geometria</translatorcomment>
        <translation type="vanished">Geometria</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Specific Properties</source>
        <translation>Propriedades específicas</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Dependent Entities</source>
        <translation>Entidades Dependentes</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Custom</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Customize..
Personalizado
Não entidades de dimensão com posições etiqueta personalizada selecionada.</translatorcomment>
        <translation>Personalizado</translation>
    </message>
    <message>
        <location line="+166"/>
        <source>Index</source>
        <translatorcomment>--google--
Indentar nó
Trocar para a próxima camada</translatorcomment>
        <translation>Índice</translation>
    </message>
    <message>
        <location line="+77"/>
        <source>Remove this property from selected objects</source>
        <translation>Remova esta propriedade dos objetos selecionados</translation>
    </message>
    <message>
        <location line="+68"/>
        <source>All</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Fecha &amp;Todos
Fecha Todos
Fecha todas as janelas</translatorcomment>
        <translation>Todos</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>Show</source>
        <translation>Mostrar</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Show all properties</source>
        <translation>Mostrar todas as propriedades</translation>
    </message>
    <message>
        <location line="+621"/>
        <source>Widgets</source>
        <translation>Widgets</translation>
    </message>
    <message>
        <source>Add Custom Property</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Adicionar propriedade personalizada</translation>
    </message>
    <message>
        <location line="-667"/>
        <source>Add custom property to selected objects</source>
        <translation>Adicione uma propriedade personalizada aos objetos selecionados</translation>
    </message>
    <message>
        <source>Left</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Esquerda acima
Em cima à esquerda
Esquerda ao meio</translatorcomment>
        <translation type="obsolete">Esquerda</translation>
    </message>
    <message>
        <source>Center</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
&amp;Centro, ponto, ângulos
Centro, ponto, ângulos
Arco com Centro, Ponto, Ângulos</translatorcomment>
        <translation type="obsolete">Centro</translation>
    </message>
    <message>
        <source>Right</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Direita ao meio
Direita abaixo
Em baixo à direita</translatorcomment>
        <translation type="obsolete">Direita</translation>
    </message>
    <message>
        <source>Aligned</source>
        <translatorcomment>--exact match--
--file: DimAligned_pt.ts--
&amp;Alinhado
Alinhado
Dimensão Alinhada</translatorcomment>
        <translation type="obsolete">Alinhado</translation>
    </message>
    <message>
        <source>Middle</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
&amp;Meio
Meio
Salta aos pontos de meio</translatorcomment>
        <translation type="obsolete">Meio</translation>
    </message>
    <message>
        <source>Fit</source>
        <translatorcomment>--google--
Ajuste à página
Ponto de ajustar primeiro
Ponto de ajustar próximo</translatorcomment>
        <translation type="obsolete">Caber</translation>
    </message>
    <message>
        <source>Top</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Deposita ao fim da garimpagem
Centro acima</translatorcomment>
        <translation type="obsolete">Topo</translation>
    </message>
    <message>
        <source>Base</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Desenhe arcos tangenciais à entidade de base
Arco tangencial à entidade de base com raio</translatorcomment>
        <translation type="obsolete">Base</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Direita abaixo
Em baixo à direita
Centro abaixo</translatorcomment>
        <translation type="obsolete">Fundo</translation>
    </message>
    <message>
        <location line="+163"/>
        <source>Auto</source>
        <translatorcomment>--exact match--
--file: SnapAuto_pt.ts--
&amp;Auto
Auto
Salta automaticamente</translatorcomment>
        <translation>Automático</translation>
    </message>
    <message>
        <location line="+128"/>
        <source>Use auto measurement</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Use medição automática</translation>
    </message>
    <message>
        <location line="+39"/>
        <source>Yes</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Sim
Ontem</translatorcomment>
        <translation>Sim</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>No</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Não pôde abrir o arquivo
%1
Por favor verifique as permissões.
Não pôde abrir o arquivo
%1
Por favor verifique as permissões
Não pôde salvar o arquivo
%1
Por favor verifique as permissões.</translatorcomment>
        <translation>Não</translation>
    </message>
    <message>
        <location line="+336"/>
        <location line="+57"/>
        <location line="+11"/>
        <source>Property Editor</source>
        <translatorcomment>--exact match--
--file: qcad_pt.ts--
Editor de Propriedades</translatorcomment>
        <translation>Editor de Propriedades</translation>
    </message>
    <message>
        <location filename="../PropertyEditor.ui" line="+40"/>
        <source>Selection:</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Selecção:</translatorcomment>
        <translation>Seleção:</translation>
    </message>
    <message>
        <source>General</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Preferências Gerais do Aplicativo
[2000-206F] Pontuação Geral</translatorcomment>
        <translation type="vanished">Geral</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>General Properties</source>
        <translation>Propriedades gerais</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Color:</source>
        <translation>Cor:</translation>
    </message>
    <message>
        <source>Move Selection to a New Layer</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="vanished">Mova a Seleção para uma Nova Camada</translation>
    </message>
    <message>
        <location line="+104"/>
        <source>Linetype Scale:</source>
        <translation>Escala do Tipo de Linha:</translation>
    </message>
    <message>
        <location line="+49"/>
        <source>Protected:</source>
        <translation>Protegido:</translation>
    </message>
    <message>
        <location line="-143"/>
        <source>Handle:</source>
        <translatorcomment>--ignored colon--
--file: pt.po--</translatorcomment>
        <translation>Manipulador:</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Display Z coordinates</source>
        <translation>Exiba coordenadas Z</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Display properties of current block and current layer</source>
        <translation>Exibição de propriedades de bloco atual e camada atual</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Allow adding custom properties</source>
        <translation>Permitir a adição de propriedades personalizadas</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Always show all properties (this may slow down selection of entities)</source>
        <translation>Sempre mostrar todas as propriedades (isso pode retardar a seleção de entidades)</translation>
    </message>
</context>
</TS>
